.. _combinatiorics-docs:

====================
Combinatorics Module
====================

Contents
========

.. toctree::
   :maxdepth: 2

   partitions.rst
   permutations.rst
   perm_groups.rst
   polyhedron.rst
   prufer.rst
   subsets.rst
   graycode.rst
   named_groups.rst
   util.rst
   group_constructs.rst
   testutil.rst
